@@ -29,7 +29,7 @@ public:
     enum Attribute {RADIUS, ATTRIBUTE_COUNT};
     BlurEffect();
     virtual bool setAttribute(QString const& name, QString const& value);
-    virtual void apply(QGraphicsItem* item);
+    virtual void apply(GraphicsElement* item);
 
 private:
     QGraphicsBlurEffect* effect_;
